%% Test Domains
%
% A set of domains that is mapped to the unit disk.
% The spatial density is measured and projected back into the original
% domain
%

%% Angle changes
% A protrusion into the domain. The angle of the protrusion is decreased in
% aBox2
aBox = [-1-1i 0 1-1i 2-1i 2+1i -2+1i -2-1i -1-1i];
ConformalMapper(aBox, 0 + 0.5j, -1+0.1i, 1+0.1i, [-1+0.1i, 1+0.1i]);

aBox2 = [-0.01-1i 0 0.01-1i 2-1i 2+1i -2+1i -2-1i -0.01-1i];
ConformalMapper(aBox2, 0 + 0.5j, -1+0.1i, 1+0.1i, [-1+0.1i, 1+0.1i]);

%% Height change
% A protrusion into the domain. The angle is constant, but the height is
% changed
alpha = pi/3;
offset = @(h) tan(alpha/2)*h;

r = 1;
aBox = [-offset(r)-1i (-1+r)*1j offset(r)-1i 2-1i 2+1i -2+1i -2-1i -offset(r)-1i];
ConformalMapper(aBox, 0 + 0.5j);

r = 0.66;
aBox2 = [-offset(r)-1i (-1+r)*1j offset(r)-1i 2-1i 2+1i -2+1i -2-1i -offset(r)-1i];
ConformalMapper(aBox2, 0 + 0.5j);

r = 0.33;
aBox3 = [-offset(r)-1i (-1+r)*1j offset(r)-1i 2-1i 2+1i -2+1i -2-1i -offset(r)-1i];
ConformalMapper(aBox3, 0 + 0.5j);

%% Retrusion
% A retrusion out of the domain. The angle is decreased in vBox1
vBox = [-1-1i -2i 1-1i 2-1i 2+1i -2+1i -2-1i -1-1i];
ConformalMapper(vBox, 0 + 0.5j, -1-0.5i, 1-0.5i, [-1-0.5i, 1-0.5i]);

vBox1 = [-0.01-1i -2i 0.01-1i 2-1i 2+1i -2+1i -2-1i -0.5-1i];
ConformalMapper(vBox1, 0 + 0.5j, -1-0.5i, 1-0.5i, [-1-0.5i, 1-0.5i]);

%%
hBox = [-2-1j -1-1j -1-0.5j 1-0.5j 1-1j 2-1j 2+1j 1+1j 1+0.5j -1+0.5j -1+1j -2+1j -2-1j];
ConformalMapper(hBox, 0);

%%
xBox = [1-1j 2-1j 2+1j 1+1j 1+2j -1+2j -1+1j -2+1j -2-1j -1-1j -1-2j 1-2j 1-1j];
ConformalMapper(xBox, 0);

%%
cBox = [1-1j 1-0.5j 0.5-0.5j 0.5+0.5j 1+0.5j 1+1j -0.5+1j -0.5-1j 1-1j];
ConformalMapper(cBox, -0.25);

%%
zBox = [1.5-1.5j 1.5-0.5j 0.5-0.5j 0.5+1.5j -1.5+1.5j -1.5+0.5j -0.5+0.5j -0.5-1.5j 1.5-1.5j];
ConformalMapper(zBox, 0);

%% Uneven sharpness
% A domain with two protrusions with different sharpness. A path is plotted
% in the middle to see the effect on of the warping on an unobstructed
% shortest path

unevenSharpnessX = [0.5 1+0.1j 1+1j -1+1j -1+0.5j -0.5 -1-0.5j -1-1j 1-1j 1-0.1j 0.5];
ConformalMapper(unevenSharpnessX, 0, -0.75j, 0.75j, [-0.75j 0.75j]);

%%
alpha = pi/3;
offset = @(h) tan(alpha/2)*h;
r1 = 0.8;
r2 = 0.2;
unevenSizeX = [1-r1 1+offset(r1)*1j 1+1j -1+1j -1+offset(r2)*1j r2-1 -1-offset(r2)*1j -1-1j 1-1j 1-offset(r1)*1j 1-r1];
ConformalMapper(unevenSizeX, 0);

%%
unevenComb = [-2-1i -1.5-1i -1-0.5i -0.5-1i -0.25-1i -0.5i 0.25-1i 0.9-1i 1-0.5i 1.1-1i 2-1i  2+1i -2+1i -2-1i];
ConformalMapper(unevenComb, 0);

%% Zigzag
zigZag = [0.5-2j 0.5-1.5j -1.5j -1j 0.5-1j 0.5+0.5j 0.5j 1j 0.5+1j 0.5+2.5j -0.5+2.5j -0.5+2j 2j 1.5j -0.5+1.5j -0.5  0 -0.5j -0.5-0.5j -0.5-2j 0.5-2j];
ConformalMapper(zigZag,0.25-0.25j );

%%
keyBox = [0.5-1j 0.5+2.5j -2+2.5j -2+1.5j -0.5+1.5j -0.5 -1 -1+1j -2+1j -2 -3 -3-1j 0.5-1j];
ConformalMapper(keyBox*(-1)+1+0.5i, 1, 2.5-1.5i, 3+1i);